phitigra: Graph editor for SageMath/Jupyter
===========================================

Description
-----------

Graph editor for SageMath/Jupyter

License
-------

Upstream Contact
----------------

https://pypi.org/project/phitigra/

